@@ -230,11 +230,13 @@ class DearBagPlayer:
         """
         TODO: Consider multiple timelines for multiple topics
         """
-        if self.__timeline.isPlayed():
+        if self.__timeline.is_played or self.__timeline.is_stopped:
             if len(self.msg_data_pool) == 0:
                 return
             self.vlinesTimeUpdate(self.__timeline.now())
             self.xypointsUpdate()
+            if self.__timeline.is_stopped:
+                self.__timeline.resetIsStopped()
 
     def vlinesTimeUpdate(self, timestamp):
         if not self.vlines:
@@ -296,6 +298,12 @@ class DearBagPlayer:
         self.xypoints = None
 
     def createTimeLines(self):
+        # Check if act_plot is deleted by users
+        try:
+            dpg.get_item_info(dpg.get_item_user_data(self.tab_bar)['act_plot'])
+        except:
+            return
+
         act_plot = dpg.get_item_user_data(self.tab_bar)['act_plot']
         plots = dpg.get_item_info(act_plot)['children'][1]
 
@@ -308,6 +316,12 @@ class DearBagPlayer:
                 self.vlines.append(vline_tag)
 
     def createTimePoints(self):
+        # Check if act_plot is deleted by users
+        try:
+            dpg.get_item_info(dpg.get_item_user_data(self.tab_bar)['act_plot'])
+        except:
+            return
+
         act_plot = dpg.get_item_user_data(self.tab_bar)['act_plot']
         plots = dpg.get_item_info(act_plot)['children'][1]
 
@@ -343,6 +357,7 @@ class DearBagPlayer:
 
             # Check they belongs to the same topic and bag
             if datax[3] != datay[3] or datax[4] != datay[4]:
+                # TODO: use popup and return instead of Exception
                 raise ValueError("XY plot must comes from the same bag and topic!")
 
             # Plot line series
@@ -367,6 +382,7 @@ class DearBagPlayer:
             datay = dpg.get_item_user_data(app_data[1])
             # Check they belongs to the same topic and bag
             if datax[3] != datay[3] or datax[4] != datay[4]:
+                # TODO: use popup and return instead of Exception
                 raise ValueError("Data vs. s plot must comes from the same bag and topic!")
 
             # Plot line series
@@ -471,6 +487,7 @@ class DearBagPlayer:
             label=title, height=height, width=width, equal_aspects=equal_aspects, payload_type="plotting",
             drop_callback=plot_drop_callback, parent=parent,
         )
+        dpg.add_plot_legend(parent=plot_tag)
         dpg.add_plot_axis(dpg.mvXAxis, label=x_label, parent=plot_tag)
         dpg.add_plot_axis(dpg.mvYAxis, label=y_label, payload_type="plotting",
                           parent=plot_tag, drop_callback=axis_drop_callback)
@@ -575,6 +592,24 @@ class DearBagPlayer:
     def deleteClosedTab(self):
         for tab in dpg.get_item_children(self.tab_bar)[1]:
             if not dpg.get_item_configuration(tab)['show']:
+                # Stop playback before delete
+                if tab == dpg.get_item_user_data(self.tab_bar)['act_tab']:
+                    self.__timeline.stop()
+                # Remove vlines and xypoints from lists before delete tab
+                for figure in dpg.get_item_children(dpg.get_item_children(tab)[1][0])[1]:
+                    if self.vlines is not None:
+                        self.vlines = [
+                            vline
+                            for vline in self.vlines
+                            if vline not in dpg.get_item_children(dpg.get_item_children(figure)[1][1])[1]
+                        ]
+                    if self.xypoints is not None:
+                        self.xypoints = [
+                            xypoint
+                            for xypoint in self.xypoints
+                            if xypoint not in dpg.get_item_children(dpg.get_item_children(figure)[1][1])[1]
+                        ]
+                # Delete tab
                 dpg.delete_item(tab)
 
     # -----------------------------------------
